## Utilisation de formats personnalisés dans Qualigéo

Les formats personnalisés peuvent être exploités par Qualigéo. Ils permettent d’exploiter toute la puissance de FME dans le prétraitement des données à contrôler : certaines contraintes ne peuvent pas être paramétrées dans un unique schéma de contraintes dans Qualigéo. Une méthode permet d’effectuer des vérifications supplémentaires à celles proposées par le logiciel en concevant un projet FME de contrôles sur les éléments non paramétrables dans Qualigéo, puis d’exporter le projet FME en tant que format personnalisé.

De la sorte, l’intégralité des règles du schéma de contraintes et du format personnalisé est vérifiée lors d’un seul contrôle dans Qualigéo.

Intégrer un format personnalisé dans Qualigéo permet par exemple de :

*   Contrôler un jeu de données contenant plusieurs formats
*   Contrôler l’arborescences de fichiers dans un jeu de données
*   Contrôler des relations de cardinalités particulières...

Si l’administrateur choisit d’intégrer les formats personnalisés, il est alors possible de rajouter ces formats, de la même façon qu’un [format classique](../Interface%20de%20Qualigéo/Outils/interface%20administration.htm#Gestion_des_Formats), en fournissant le nom du format personnalisé tel qu’il a été défini dans FME, sa description, son type et son extension.

Des erreurs spécifiques au projet du format personnalisé peuvent être créées dans FME et transmises à Qualigéo lors du contrôle.

==> "Erreur retournée : E0055 (Erreur définie et testée dans le format personnalisé)

### 1 Démarche d’intégration et d’utilisation d’un format personnalisé

1.  Création du format personnalisé dans FME (\*.fds).
2.  Installation du format personnalisé sur le serveur
3.  Intégration du format personnalisé dans Qualigéo
4.  Contrôle de jeu de données (pré traitement via le format personnalisé).

### 2 Exemple de création d’un format personnalisé

#### 2.1 Création d’un format personnalisé dans FME (\*.fds)

Pour pouvoir être exploité par Qualigéo et générer des erreurs spécifiques aux format personnalisé, le projet de création de format personnalisé doit contenir les éléments suivants :

*   FeatureReader : Transformer de lecture du schéma et des données à contrôler

*   Writer ’SCHEMA_QUALIGEO_FP’, relié au port Schéma de la donnée à lire : Écriture du schéma exploité lors du contrôle.
*   Writer ’ERREURS_QUALIGEO_FP’, type d’entité en sortie stockant l’erreur de type E0055 à générer avec son propre message d’erreur stocké dans l’attribut ’message’.
*   Writer ’Généric’, relié au port Généric, permet de générer les types d’entité dynamiquement pour être exploités en phase de contrôle.

En phase de contrôle, les 3 types d’entité ainsi générés sont exploités pour générer l’erreur désirée.

**Exemple de projet de création de format personnalisé pour contrôler la couleur d’affichage des villes françaises au format Mapinfo : check_color.fds**

![](../Ressources/Images/fds.png)

#### 2.2 Installation du format personnalisé sur le serveur

Pour pouvoir être exploité, le format personnalisé est ensuite installé sur le serveur où est installé Qualigéo.

Un double clic sur le fichier .fds permet d’installer le format personnalisé dans le répertoire FORMATS (%userprofile%\Mes documents\FME\Formats)

#### 2.3 Ajout du format personnalisé dans Qualigéo

L’intégration de format personnalisé se fait de la même façon qu’un **[format classique,](../Interface%20de%20Qualigéo/Outils/interface%20administration.htm#Gestion_des_Formats)** en renseignant l’ensemble des champs. de la fenêtre d’ajout de format.

![](../Ressources/Images/ajout_fds.png)

![](../Ressources/Images/attention.png) <span style="font-family: Calibri;">Il est conseillé d’insérer la même valeur pour les champs ’id Format’ et ’Format’.</span>

![](../Ressources/Images/attention.png) Dans le cas de format personnalisé, il faut décocher la case ’Utilisable pour l’export des contrôles’.

![](../Ressources/Images/attention.png)La sélection de l’option "Utiliser comme format personnalisé" affiche la valeur PATH comme format de schéma. Le "PATH" indique l’utilisation d’un format personnalisé dans le contrôle. Le projet de contrôle exploite alors le type d’entité schéma ’SCHEMA_QUALIGEO_FP’ généré lors de la conception du format personnalisé Writer ’SCHEMA_QUALIGEO_FP.

Le format personnalisé est ensuite ajouté à la liste des formats exploitables par Qualigéo.

Une fois intégré, un format personnalisé peut être contrôlé comme tout autre fichier classique.

#### 2.4 Contrôle d’un jeu de données

Un prétraitement permet le contrôle des données comme s’il s’agissait d’une une unique source de données à contrôler. Puis le contrôle Qualigéo s’opère selon le schéma de contrainte sélectionné.

La couleur de données Mapinfo est désormais "contrôlable" dans Qualigéo en exploitant le format personnalisé précédemment créé.

![](../Ressources/Images/controle_fds_507x494.png)

### 3. Exemple du format personnalisé du standard de données GRACE THD

Veremes a développé certains formats personnalisés spécifiques aux géo standards tels qui sont définis par le CNIG et la COVADIS (PLU, GRACETHD, PCRS). Pour connaître les formats disponibles et leur conditions d’utilisation, veuillez contacter le service [support de Veremes](../Support_technique.htm).

Le standard de données GRACE THD constitue le référentiel en matière d’aménagement numérique des territoires. L’échange des données GRACE se fait via des fichiers au format Shapefile (données géographiques) et au format CSV pour les données non géographiques. De telles données ne peuvent pas être contrôlées par un unique schéma dans Qualigéo. Par exemple, les relations entre deux tables de format différent ne pourraient pas être vérifiées. Un format personnalisé basé sur le regroupement de ces deux formats permet donc de contourner cette contrainte.

*   Conception du formats personnalisé GRACE

Dans FME, un projet est développé pour regrouper et pré traiter les fichiers des deux formats, il vérifie l’intégralité d’un jeu de données GRACE. En premier lieu le projet décompresse les données fournies au format ZIP, puis regroupe les sources de données. Des contrôles de cardinalités spécifiques (non possibles dans Qualigéo) sont ensuite implémentés en fin de traitement, et permette de retourner des erreurs spécifiques avec un message adapté à chaque erreur de cardinalité. Par exemple, "La relation de cardinalité n’est pas respectée avec la table "t_adresse". L’attribut a pour valeur "@Value(pt_ad_code)".

<span style="color: #943a99; font-family: Calibri; font-size: 11pt;">==> Erreur retournée : E0055</span>

Le projet, ainsi conçu, est exporté en format personnalisé (\*.fds).
